@@ -6,9 +6,10 @@ import htmlmin
 import mako.lookup
 from mako.filters import html_escape
 
+from .config import Markup
+from .docstring import parse_docstring
 from .rst import convert_rst_to_html
-from .unit import Module, Function, Class, UnitChild, Unit
-
+from .unit import Class, Function, Module, UnitChild
 
 #  from .rst import convert_rst_to_html
 
@@ -52,31 +53,23 @@ class RenderContext:
             return "{}#line-{}".format(url, unit.lineno - 1)
 
     def format_code(self, code):
+        from pygments import highlight, lexers
         from pygments.formatters import HtmlFormatter
-        from pygments import lexers
-        from pygments import highlight
 
         formatter = HtmlFormatter(linenos=True, lineanchors="line")
         lexer = lexers.get_lexer_by_name("python")
         return highlight(code, lexer, formatter)
 
-    def render_docstring(self, unit_or_docstring):
-        if isinstance(unit_or_docstring, Unit):
-            docstring = unit_or_docstring.docstring
-        elif isinstance(unit_or_docstring, str):
-            docstring = unit_or_docstring
-        else:
-            assert False
-
-        escaped = html_escape(docstring)
-        if self.gctx.config.markup == "rst":
-            content = convert_rst_to_html(escaped)
+    def render_paragraph(self, text):
+        if self.gctx.config.markup == Markup.RST:
+            content = convert_rst_to_html(text)
             return "<div class='rst-documentation'>{}</div>".format(content)
         else:
+            escaped = html_escape(text)
             return "<pre>{}</pre>".format(escaped)
 
-    def render_docline(self, unit):
-        return unit.docline
+    def get_parsed_docstring(self, unit):
+        return parse_docstring(self.gctx.config.style, unit.docstring)
 
 
 class Renderer:
